@@ -1,4 +1,4 @@
-/* GrandPerspective, Version 2.5.2 
+/* GrandPerspective, Version 2.5.3 
  *   A utility for Mac OS X that graphically shows disk usage. 
  * Copyright (C) 2005-2020, Erwin Bonsma 
  * 
@@ -313,8 +313,6 @@ NSMutableDictionary  *createToolbarItemLookup = nil;
   item.label = title;
   item.paletteLabel = item.label;
   item.view = zoomControls;
-  item.minSize = zoomControls.bounds.size;
-  item.maxSize = zoomControls.bounds.size;
   
   // Tool tips set here (as opposed to Interface Builder) so that all toolbar-related text is in the
   // same file, to facilitate localization.
@@ -360,8 +358,6 @@ NSMutableDictionary  *createToolbarItemLookup = nil;
   item.label = title;
   item.paletteLabel = item.label;
   item.view = focusControls;
-  item.minSize = focusControls.bounds.size;
-  item.maxSize = focusControls.bounds.size;
 
   // Tool tips set here (as opposed to Interface Builder) so that all toolbar-related text is in the
   // same file, to facilitate localization.
