@@ -1,4 +1,4 @@
-/* GrandPerspective, Version 2.5.2 
+/* GrandPerspective, Version 2.5.3 
  *   A utility for Mac OS X that graphically shows disk usage. 
  * Copyright (C) 2005-2020, Erwin Bonsma 
  * 
@@ -556,7 +556,7 @@ didStartElement:(NSString *)elementName
     error = 
       [[ApplicationError alloc] initWithLocalizedDescription:
           [NSString stringWithFormat: PARSE_ERROR_MSG,
-                      parser.lineNumber,
+                      (int)parser.lineNumber,
                       parseError.localizedDescription]];
   }
 }
