@@ -1,4 +1,4 @@
-/* GrandPerspective, Version 2.5.2 
+/* GrandPerspective, Version 2.5.3 
  *   A utility for Mac OS X that graphically shows disk usage. 
  * Copyright (C) 2005-2020, Erwin Bonsma 
  * 
@@ -47,13 +47,9 @@ NSColor* colorForHexString(NSString* hexColor) {
   return [NSColor colorWithDeviceRed:r green:g blue:b alpha:0];
 }
 
-NSColorList* createFallbackPalette() {
+NSColorList* createPalette(NSArray *colors) {
   NSColorList  *colorList = [[[NSColorList alloc] initWithName: fallbackColorListName] autorelease];
 
-  // Hardcoded CoffeeBeans palette
-  NSArray  *colors = [NSArray arrayWithObjects: @"CC3333", @"CC9933", @"FFCC66", @"CC6633",
-                                                @"CC6666", @"993300", @"666600", nil];
-
   int count = 0;
   for (id colorString in colors) {
     [colorList insertColor: colorForHexString(colorString) key: colorString atIndex: count++];
@@ -62,6 +58,23 @@ NSColorList* createFallbackPalette() {
   return colorList;
 }
 
+NSColorList* createFallbackPalette() {
+  // Hardcoded CoffeeBeans palette
+  NSArray  *colors = [NSArray arrayWithObjects: @"CC3333", @"CC9933", @"FFCC66", @"CC6633",
+                                                @"CC6666", @"993300", @"666600", nil];
+
+  return createPalette(colors);
+}
+
+#ifdef ENABLE_PALETTE_GRANDPERSPECTIVE
+NSColorList* createGrandPerspectivePalette() {
+  // Hardcoded "GrandPerspective" palette
+  NSArray  *colors = [NSArray arrayWithObjects: @"35B7DA", @"61D7D7", @"679DB4", @"538CA7", nil];
+
+  return createPalette(colors);
+}
+#endif
+
 @interface ColorListCollection (PrivateMethods)
 - (bool) isEmpty;
 @end
@@ -92,7 +105,11 @@ NSColorList* createFallbackPalette() {
       NSLog(@"Failed to load any palette. Adding fallback palette");
       [instance addColorList: createFallbackPalette() key: fallbackColorListKey];
     }
-    
+
+#ifdef ENABLE_PALETTE_GRANDPERSPECTIVE
+    [instance addColorList: createGrandPerspectivePalette() key: @"GrandPerspective"];
+#endif
+
     defaultColorListCollectionInstance = [instance retain];
   }
   
