@@ -1,4 +1,4 @@
-/* GrandPerspective, Version 2.5.2 
+/* GrandPerspective, Version 2.5.3 
  *   A utility for Mac OS X that graphically shows disk usage. 
  * Copyright (C) 2005-2020, Erwin Bonsma 
  * 
@@ -172,8 +172,6 @@
 		[button setButtonType:NSMomentaryChangeButton];
 		[button setBordered:NO];
 		self.view = button;
-		self.minSize = NSMakeSize(32,32);
-		self.maxSize = NSMakeSize(32,32);
 	}
 	return self;
 }
